@@ -1,13 +1,15 @@
 
 fn main() {
+
     // Skip linking on docs.rs: https://docs.rs/about/builds#detecting-docsrs
     let building_docs = std::env::var("DOCS_RS").is_ok();
+    if building_docs {
+        return;
+    };
 
-    if !building_docs {
-        let dst = cmake::Config::new("ptex-c").build();
-        println!("cargo:rustc-link-search=native={}", dst.display());
-        println!("cargo:rustc-link-lib=dylib=ptex-c-0_0");
-    }
+    let dst = cmake::Config::new("ptex-c").build();
+    println!("cargo:rustc-link-search=native={}", dst.display());
+    println!("cargo:rustc-link-lib=dylib=ptex-c-0_0");
 
     let out_dir = std::env::var("OUT_DIR").unwrap();
     let output = std::process::Command::new("python")
@@ -24,10 +26,6 @@ fn main() {
         panic!("failed");
     }
 
-    if building_docs {
-        return;
-    }
-
     println!("cargo:rustc-link-search=native=ptex/dist/lib64");
     println!("cargo:rustc-link-search=native=ptex/dist/lib");
     println!("cargo:rustc-link-lib=dylib=Ptex");
